==> senior_design_system-0.21.4.tar.gz: example/lib/pages/button.example.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/panel.dart';
import '../widgets/page_wrapper.dart';

class ButtonExample extends StatefulWidget {
  const ButtonExample({Key? key}) : super(key: key);

  @override
  _ButtonExampleState createState() => _ButtonExampleState();
}

class _ButtonExampleState extends State<ButtonExample> {
  bool _isDisabled = false;
  bool _isBusy = false;

  void _showSnackbar({
    required BuildContext context,
    required String message,
  }) {
    final scaffold = ScaffoldMessenger.of(context);
    scaffold.showSnackBar(
      SnackBar(
        content: Text(message),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Button',
      child: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.only(top: 16.0),
          child: Column(
            children: [
              SeniorSwitch(
                title: 'Habilitar botões',
                value: !_isDisabled,
                onChanged: (value) {
                  if (value == null) return;
                  setState(() {
                    _isDisabled = !value;
                  });
                },
                titlePosition: SeniorSwitchTitlePosition.right,
              ),
              Padding(
                padding: const EdgeInsets.all(16.0),
                child: Column(
                  children: [
                    Panel(
                      title: 'Primary button',
                      child: SeniorButton(
                        label: 'Salvar',
                        onPressed: () => _showSnackbar(
                          context: context,
                          message: 'Clicou sobre o botão Salvar com largura ocupando todo o espaço disponível',
                        ),
                        disabled: _isDisabled,
                        fullLength: true,
                        size: SeniorButtonSize.big,
                        type: SeniorButtonType.primary,
                      ),
                    ),
                    Panel(
                      title: 'Secondary button',
                      child: SeniorButton(
                        label: 'Revisar',
                        onPressed: () => _showSnackbar(
                          context: context,
                          message: 'Clicou sobre o botão Revisar com largura ocupando todo o espaço disponível',
                        ),
                        disabled: _isDisabled,
                        fullLength: true,
                        size: SeniorButtonSize.big,
                        type: SeniorButtonType.secondary,
                      ),
                    ),
                    Panel(
                      title: 'Ghost button',
                      child: SeniorButton(
                        label: 'Cancelar',
                        onPressed: () => _showSnackbar(
                          context: context,
                          message: 'Clicou sobre o botão Cancelar com largura ocupando todo o espaço disponível',
                        ),
                        disabled: _isDisabled,
                        fullLength: true,
                        size: SeniorButtonSize.big,
                        type: SeniorButtonType.ghost,
                      ),
                    ),
                    Panel(
                      title: 'Danger button',
                      child: SeniorButton(
                        label: 'Excluir',
                        onPressed: () => _showSnackbar(
                          context: context,
                          message: 'Clicou sobre o botão Excluir com largura ocupando todo o espaço disponível',
                        ),
                        disabled: _isDisabled,
                        fullLength: true,
                        size: SeniorButtonSize.big,
                        type: SeniorButtonType.danger,
                      ),
                    ),
                    Panel(
                      title: 'Aligned button',
                      child: Row(
                        children: [
                          Expanded(
                            child: SeniorButton(
                              label: 'OK',
                              onPressed: () => _showSnackbar(
                                context: context,
                                message: 'Clicou sobre o botão Salvar.',
                              ),
                              disabled: _isDisabled,
                              fullLength: true,
                              size: SeniorButtonSize.big,
                              type: SeniorButtonType.primary,
                            ),
                          ),
                          SizedBox(width: 16.0),
                          Expanded(
                            child: SeniorButton(
                              label: 'Editar',
                              onPressed: () => _showSnackbar(
                                context: context,
                                message: 'Clicou sobre o botão Revisar',
                              ),
                              disabled: _isDisabled,
                              fullLength: true,
                              size: SeniorButtonSize.big,
                              type: SeniorButtonType.secondary,
                            ),
                          ),
                          SizedBox(width: 16.0),
                          Expanded(
                            child: SeniorButton(
                              label: 'Sair',
                              onPressed: () => _showSnackbar(
                                context: context,
                                message: 'Clicou sobre o botão Cancelar',
                              ),
                              disabled: _isDisabled,
                              fullLength: true,
                              size: SeniorButtonSize.big,
                              type: SeniorButtonType.ghost,
                            ),
                          ),
                        ],
                      ),
                    ),
                    Panel(
                      title: 'Primary button with icon',
                      child: SeniorButton.icon(
                        icon: FontAwesomeIcons.search,
                        label: 'Pesquisar',
                        onPressed: () => _showSnackbar(
                          context: context,
                          message: 'Clicou sobre o botão Pesquisar que possui ícone',
                        ),
                        disabled: _isDisabled,
                        fullLength: true,
                        size: SeniorButtonSize.small,
                        type: SeniorButtonType.primary,
                      ),
                    ),
                    Panel(
                      title: 'Secondary button with icon',
                      child: SeniorButton.icon(
                        icon: FontAwesomeIcons.edit,
                        label: 'Editar',
                        onPressed: () => _showSnackbar(
                          context: context,
                          message: 'Clicou sobre o botão Editar que possui ícone',
                        ),
                        disabled: _isDisabled,
                        fullLength: true,
                        size: SeniorButtonSize.small,
                        type: SeniorButtonType.secondary,
                      ),
                    ),
                    Panel(
                      title: 'Ghost button with icon',
                      child: SeniorButton.icon(
                        icon: FontAwesomeIcons.times,
                        label: 'Fechar',
                        onPressed: () => _showSnackbar(
                          context: context,
                          message: 'Clicou sobre o botão Fechar que possui ícone',
                        ),
                        disabled: _isDisabled,
                        fullLength: true,
                        size: SeniorButtonSize.small,
                        type: SeniorButtonType.ghost,
                      ),
                    ),
                    Panel(
                      title: 'Button with progress animation',
                      child: SeniorButton(
                        label: 'Progress',
                        onPressed: () {
                          setState(() {
                            _isBusy = !_isBusy;
                          });
                        },
                        disabled: _isDisabled,
                        fullLength: true,
                        size: SeniorButtonSize.big,
                        type: SeniorButtonType.primary,
                        busy: _isBusy,
                        busyMessage: 'Botão ocupado',
                      ),
                    ),
                  ],
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

==> senior_design_system-2.1.3.tar.gz: example/lib/pages/button.example.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/panel.dart';
import '../widgets/page_wrapper.dart';

class ButtonExample extends StatefulWidget {
  const ButtonExample({Key? key}) : super(key: key);

  @override
  _ButtonExampleState createState() => _ButtonExampleState();
}

class _ButtonExampleState extends State<ButtonExample> {
  bool _isDisabled = false;
  bool _isBusy = false;

  void _showSnackbar({
    required BuildContext context,
    required String message,
  }) {
    final scaffold = ScaffoldMessenger.of(context);
    scaffold.showSnackBar(
      SnackBar(
        content: Text(message),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Button',
      child: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.only(top: 16.0),
          child: Column(
            children: [
              SeniorSwitch(
                title: 'Habilitar botões',
                value: !_isDisabled,
                onChanged: (value) {
                  if (value == null) {
                    return;
                  }
                  setState(() {
                    _isDisabled = !value;
                  });
                },
                titlePosition: SeniorSwitchTitlePosition.right,
              ),
              Padding(
                padding: const EdgeInsets.all(16.0),
                child: Column(
                  children: [
                    Panel(
                      title: 'Primary button',
                      child: SeniorButton(
                        label: 'Salvar',
                        onPressed: () => _showSnackbar(
                          context: context,
                          message:
                              'Clicou sobre o botão Salvar com largura ocupando todo o espaço disponível',
                        ),
                        disabled: _isDisabled,
                        fullLength: true,
                        size: SeniorButtonSize.big,
                        type: SeniorButtonType.primary,
                      ),
                    ),
                    Panel(
                      title: 'Secondary button',
                      child: SeniorButton(
                        label: 'Revisar',
                        onPressed: () => _showSnackbar(
                          context: context,
                          message:
                              'Clicou sobre o botão Revisar com largura ocupando todo o espaço disponível',
                        ),
                        disabled: _isDisabled,
                        fullLength: true,
                        size: SeniorButtonSize.big,
                        type: SeniorButtonType.secondary,
                      ),
                    ),
                    Panel(
                      title: 'Ghost button',
                      child: SeniorButton(
                        label: 'Cancelar',
                        onPressed: () => _showSnackbar(
                          context: context,
                          message:
                              'Clicou sobre o botão Cancelar com largura ocupando todo o espaço disponível',
                        ),
                        disabled: _isDisabled,
                        fullLength: true,
                        size: SeniorButtonSize.big,
                        type: SeniorButtonType.ghost,
                      ),
                    ),
                    Panel(
                      title: 'Danger button',
                      child: SeniorButton(
                        label: 'Excluir',
                        onPressed: () => _showSnackbar(
                          context: context,
                          message:
                              'Clicou sobre o botão Excluir com largura ocupando todo o espaço disponível',
                        ),
                        disabled: _isDisabled,
                        fullLength: true,
                        size: SeniorButtonSize.big,
                        type: SeniorButtonType.danger,
                      ),
                    ),
                    Panel(
                      title: 'Aligned button',
                      child: Row(
                        children: [
                          Expanded(
                            child: SeniorButton(
                              label: 'OK',
                              onPressed: () => _showSnackbar(
                                context: context,
                                message: 'Clicou sobre o botão Salvar.',
                              ),
                              disabled: _isDisabled,
                              fullLength: true,
                              size: SeniorButtonSize.big,
                              type: SeniorButtonType.primary,
                            ),
                          ),
                          const SizedBox(width: 16.0),
                          Expanded(
                            child: SeniorButton(
                              label: 'Editar',
                              onPressed: () => _showSnackbar(
                                context: context,
                                message: 'Clicou sobre o botão Revisar',
                              ),
                              disabled: _isDisabled,
                              fullLength: true,
                              size: SeniorButtonSize.big,
                              type: SeniorButtonType.secondary,
                            ),
                          ),
                          const SizedBox(width: 16.0),
                          Expanded(
                            child: SeniorButton(
                              label: 'Sair',
                              onPressed: () => _showSnackbar(
                                context: context,
                                message: 'Clicou sobre o botão Cancelar',
                              ),
                              disabled: _isDisabled,
                              fullLength: true,
                              size: SeniorButtonSize.big,
                              type: SeniorButtonType.ghost,
                            ),
                          ),
                        ],
                      ),
                    ),
                    Panel(
                      title: 'Primary button with icon',
                      child: SeniorButton.icon(
                        icon: FontAwesomeIcons.magnifyingGlass,
                        label: 'Pesquisar',
                        onPressed: () => _showSnackbar(
                          context: context,
                          message:
                              'Clicou sobre o botão Pesquisar que possui ícone',
                        ),
                        disabled: _isDisabled,
                        fullLength: true,
                        size: SeniorButtonSize.small,
                        type: SeniorButtonType.primary,
                      ),
                    ),
                    Panel(
                      title: 'Secondary button with icon',
                      child: SeniorButton.icon(
                        icon: FontAwesomeIcons.penToSquare,
                        label: 'Editar',
                        onPressed: () => _showSnackbar(
                          context: context,
                          message:
                              'Clicou sobre o botão Editar que possui ícone',
                        ),
                        disabled: _isDisabled,
                        fullLength: true,
                        size: SeniorButtonSize.small,
                        type: SeniorButtonType.secondary,
                      ),
                    ),
                    Panel(
                      title: 'Ghost button with icon',
                      child: SeniorButton.icon(
                        icon: FontAwesomeIcons.xmark,
                        label: 'Fechar',
                        onPressed: () => _showSnackbar(
                          context: context,
                          message:
                              'Clicou sobre o botão Fechar que possui ícone',
                        ),
                        disabled: _isDisabled,
                        fullLength: true,
                        size: SeniorButtonSize.small,
                        type: SeniorButtonType.ghost,
                      ),
                    ),
                    Panel(
                      title: 'Button with progress animation',
                      child: SeniorButton(
                        label: 'Progress',
                        onPressed: () {
                          setState(() {
                            _isBusy = !_isBusy;
                          });
                        },
                        disabled: _isDisabled,
                        fullLength: true,
                        size: SeniorButtonSize.big,
                        type: SeniorButtonType.primary,
                        busy: _isBusy,
                        busyMessage: 'Botão ocupado',
                      ),
                    ),
                  ],
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
